@@ -9,7 +9,6 @@ use super::super::{Candlestick, OrderBook, OrderBookSnapshot, Ticker, Trade, BBO
 use super::utils::fetch_symbol_id_map_spot;
 
 use lazy_static::lazy_static;
-use log::*;
 
 const EXCHANGE_NAME: &str = "zbg";
 
@@ -60,7 +59,6 @@ fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
 
 fn on_misc_msg(msg: &str) -> MiscMessage {
     if msg.contains(r#"action":"PING"#) {
-        debug!("Received {} from {}", msg, EXCHANGE_NAME);
         MiscMessage::Pong
     } else {
         MiscMessage::Normal
